.. _index_el:

************************************************
:mod:`Euphorie` -- Euphorie Risk Assessment tool
************************************************

:Author: Simplon / Wichert Akkerman
:Version: |version|

Translations
============

The following translations are available for this document:

:doc:`English <index>`
:doc:`Français <index_fr>`
Ελληνικά
Nederlands
:doc:`Deutsch <index_de>`


About
=====

Euphorie is a tool for risk assessment.  It was developed by `SYSLAB`_ and `TNO`_
in cooperation with `Simplon`_ and `Cornelis Kolbach`_ in commission of
`The European Agency for Safety and Health at Work`_ as part of the
`Healthy Workplaces`_ campaign.
   
.. _syslab: http://syslab.com/
.. _TNO: http://www.tno.nl/index.cfm?Taal=2
.. _Simplon: http://www.simplon.biz/
.. _Cornelis Kolbach: http://cornae.org/
.. _The European Agency for Safety and Health at Work: http://osha.europa.eu/en/
.. _Healthy Workplaces: http://osha.europa.eu/en/campaigns/hw2008


Introduction
============

The euphorie risk assessment tool is based on hierarchical questionnaires. A
questionnaire (or survey) covers all possible risks for a specific sector of
industry.

Each sector organisation can have one or more surveys published simultaneously.
In order to facilitate development and testing of surveys the system supports
multiple versions for a survey. Only a single version of a survey can be public
at any point in time.



Manuals
=======

.. toctree::
   :maxdepth: 1

   manuals/el/why
   manuals/el/creation-guide
   manuals/el/client
   manuals/el/admin
   manuals/el/editor

Technical Information
=====================

.. toctree::
   :maxdepth: 1

   install
   xml
   implementation/index


Change History
==============

.. toctree::
  :maxdepth: 2

  changes



Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
